@@ -1,6 +1,8 @@
 #include "modules/clock.hpp"
 
 #include <spdlog/spdlog.h>
+
+#include <iomanip>
 #if FMT_VERSION < 60000
 #include <fmt/time.h>
 #else
@@ -23,47 +25,45 @@ using waybar::waybar_time;
 waybar::modules::Clock::Clock(const std::string& id, const Json::Value& config)
     : ALabel(config, "clock", id, "{:%H:%M}", 60, false, false, true),
       current_time_zone_idx_(0),
-      is_calendar_in_tooltip_(false)
-{
+      is_calendar_in_tooltip_(false),
+      is_timezoned_list_in_tooltip_(false) {
   if (config_["timezones"].isArray() && !config_["timezones"].empty()) {
-    for (const auto& zone_name: config_["timezones"]) {
+    for (const auto& zone_name : config_["timezones"]) {
       if (!zone_name.isString() || zone_name.asString().empty()) {
         time_zones_.push_back(nullptr);
         continue;
       }
-      time_zones_.push_back(
-        date::locate_zone(
-          zone_name.asString()
-        )
-      );
+      time_zones_.push_back(date::locate_zone(zone_name.asString()));
     }
   } else if (config_["timezone"].isString() && !config_["timezone"].asString().empty()) {
-    time_zones_.push_back(
-        date::locate_zone(
-          config_["timezone"].asString()
-        )
-      );
+    time_zones_.push_back(date::locate_zone(config_["timezone"].asString()));
   }
 
-  // If all timezones are parsed and no one is good, add nullptr to the timezones vector, to mark that local time should be shown.
+  // If all timezones are parsed and no one is good, add nullptr to the timezones vector, to mark
+  // that local time should be shown.
   if (!time_zones_.size()) {
     time_zones_.push_back(nullptr);
   }
 
   if (!is_timezone_fixed()) {
-    spdlog::warn("As using a timezone, some format args may be missing as the date library haven't got a release since 2018.");
+    spdlog::warn(
+        "As using a timezone, some format args may be missing as the date library haven't got a "
+        "release since 2018.");
   }
 
-  // Check if a particular placeholder is present in the tooltip format, to know what to calculate on update.
+  // Check if a particular placeholder is present in the tooltip format, to know what to calculate
+  // on update.
   if (config_["tooltip-format"].isString()) {
     std::string trimmed_format = config_["tooltip-format"].asString();
-    trimmed_format.erase(std::remove_if(trimmed_format.begin(),
-                              trimmed_format.end(),
-                              [](unsigned char x){return std::isspace(x);}),
-               trimmed_format.end());
+    trimmed_format.erase(std::remove_if(trimmed_format.begin(), trimmed_format.end(),
+                                        [](unsigned char x) { return std::isspace(x); }),
+                         trimmed_format.end());
     if (trimmed_format.find("{" + kCalendarPlaceholder + "}") != std::string::npos) {
       is_calendar_in_tooltip_ = true;
     }
+    if (trimmed_format.find("{" + KTimezonedTimeListPlaceholder + "}") != std::string::npos) {
+      is_timezoned_list_in_tooltip_ = true;
+    }
   }
 
   if (config_["locale"].isString()) {
@@ -75,14 +75,16 @@ waybar::modules::Clock::Clock(const std::string& id, const Json::Value& config)
   thread_ = [this] {
     dp.emit();
     auto now = std::chrono::system_clock::now();
-    auto timeout = std::chrono::floor<std::chrono::seconds>(now + interval_);
-    auto diff = std::chrono::seconds(timeout.time_since_epoch().count() % interval_.count());
-    thread_.sleep_until(timeout - diff);
+    /* difference with projected wakeup time */
+    auto diff = now.time_since_epoch() % interval_;
+    /* sleep until the next projected time */
+    thread_.sleep_for(interval_ - diff);
   };
 }
 
 const date::time_zone* waybar::modules::Clock::current_timezone() {
-  return time_zones_[current_time_zone_idx_] ? time_zones_[current_time_zone_idx_] : date::current_zone();
+  return time_zones_[current_time_zone_idx_] ? time_zones_[current_time_zone_idx_]
+                                             : date::current_zone();
 }
 
 bool waybar::modules::Clock::is_timezone_fixed() {
@@ -99,7 +101,7 @@ auto waybar::modules::Clock::update() -> void {
     // As date dep is not fully compatible, prefer fmt
     tzset();
     auto localtime = fmt::localtime(std::chrono::system_clock::to_time_t(now));
-    text = fmt::format(format_, localtime);
+    text = fmt::format(locale_, format_, localtime);
   } else {
     text = fmt::format(format_, wtime);
   }
@@ -108,20 +110,26 @@ auto waybar::modules::Clock::update() -> void {
   if (tooltipEnabled()) {
     if (config_["tooltip-format"].isString()) {
       std::string calendar_lines = "";
+      std::string timezoned_time_lines = "";
       if (is_calendar_in_tooltip_) {
         calendar_lines = calendar_text(wtime);
       }
+      if (is_timezoned_list_in_tooltip_) {
+        timezoned_time_lines = timezones_text(&now);
+      }
       auto tooltip_format = config_["tooltip-format"].asString();
-      text = fmt::format(tooltip_format, wtime, fmt::arg(kCalendarPlaceholder.c_str(), calendar_lines));
+      text =
+          fmt::format(tooltip_format, wtime, fmt::arg(kCalendarPlaceholder.c_str(), calendar_lines),
+                      fmt::arg(KTimezonedTimeListPlaceholder.c_str(), timezoned_time_lines));
+      label_.set_tooltip_markup(text);
     }
   }
 
-  label_.set_tooltip_markup(text);
   // Call parent update
   ALabel::update();
 }
 
-bool waybar::modules::Clock::handleScroll(GdkEventScroll *e) {
+bool waybar::modules::Clock::handleScroll(GdkEventScroll* e) {
   // defer to user commands if set
   if (config_["on-scroll-up"].isString() || config_["on-scroll-down"].isString()) {
     return AModule::handleScroll(e);
@@ -140,7 +148,8 @@ bool waybar::modules::Clock::handleScroll(GdkEventScroll *e) {
     size_t new_idx = current_time_zone_idx_ + 1;
     current_time_zone_idx_ = new_idx == nr_zones ? 0 : new_idx;
   } else {
-    current_time_zone_idx_ = current_time_zone_idx_ == 0 ? nr_zones - 1 : current_time_zone_idx_ - 1;
+    current_time_zone_idx_ =
+        current_time_zone_idx_ == 0 ? nr_zones - 1 : current_time_zone_idx_ - 1;
   }
 
   update();
@@ -155,12 +164,35 @@ auto waybar::modules::Clock::calendar_text(const waybar_time& wtime) -> std::str
   }
 
   const date::year_month ym(ymd.year(), ymd.month());
-  const auto             curr_day = ymd.day();
+  const auto curr_day = ymd.day();
 
   std::stringstream os;
-  const auto        first_dow = first_day_of_week();
-  weekdays_header(first_dow, os);
 
+  const auto first_dow = first_day_of_week();
+  int ws{0};  // weeks-pos: side(1 - left, 2 - right)
+  int wn{0};  // weeknumber
+  if (config_["calendar-weeks-pos"].isString()) {
+    wn = (date::sys_days{date::year_month_day{ym / 1}} -
+          date::sys_days{date::year_month_day{ymd.year() / 1 / 1}})
+                 .count() /
+             7 +
+         1;
+    if (config_["calendar-weeks-pos"].asString() == "left") {
+      ws = 1;
+      // Add paddings before the header
+      os << std::string(4, ' ');
+    } else if (config_["calendar-weeks-pos"].asString() == "right") {
+      ws = 2;
+    }
+  }
+
+  weekdays_header(first_dow, os);
+  /* Print weeknumber on the left for the first row*/
+  if (ws == 1) {
+    print_iso_weeknum(os, wn);
+    os << ' ';
+    ++wn;
+  }
   // First week prefixed with spaces if needed.
   auto wd = date::weekday(ym / 1);
   auto empty_days = (wd - first_dow).count();
@@ -172,7 +204,19 @@ auto waybar::modules::Clock::calendar_text(const waybar_time& wtime) -> std::str
     if (wd != first_dow) {
       os << ' ';
     } else if (unsigned(d) != 1) {
+      if (ws == 2) {
+        os << ' ';
+        print_iso_weeknum(os, wn);
+        ++wn;
+      }
+
       os << '\n';
+
+      if (ws == 1) {
+        print_iso_weeknum(os, wn);
+        os << ' ';
+        ++wn;
+      }
     }
     if (d == curr_day) {
       if (config_["today-format"].isString()) {
@@ -181,8 +225,17 @@ auto waybar::modules::Clock::calendar_text(const waybar_time& wtime) -> std::str
       } else {
         os << "<b><u>" << date::format("%e", d) << "</u></b>";
       }
-    } else {
+    } else if (config_["format-calendar"].isString()) {
+      os << fmt::format(config_["format-calendar"].asString(), date::format("%e", d));
+    } else
       os << date::format("%e", d);
+    /*Print weeks on the right when the endings with spaces*/
+    if (ws == 2 && d == last_day) {
+      empty_days = 6 - (wd.c_encoding() - first_dow.c_encoding());
+      if (empty_days > 0) {
+        os << std::string(empty_days * 3 + 1, ' ');
+        print_iso_weeknum(os, wn);
+      }
     }
   }
 
@@ -194,21 +247,58 @@ auto waybar::modules::Clock::calendar_text(const waybar_time& wtime) -> std::str
 
 auto waybar::modules::Clock::weekdays_header(const date::weekday& first_dow, std::ostream& os)
     -> void {
+  std::stringstream res;
   auto wd = first_dow;
   do {
-    if (wd != first_dow) os << ' ';
+    if (wd != first_dow) res << ' ';
     Glib::ustring wd_ustring(date::format(locale_, "%a", wd));
     auto clen = ustring_clen(wd_ustring);
     auto wd_len = wd_ustring.length();
     while (clen > 2) {
-      wd_ustring = wd_ustring.substr(0, wd_len-1);
+      wd_ustring = wd_ustring.substr(0, wd_len - 1);
       wd_len--;
       clen = ustring_clen(wd_ustring);
     }
     const std::string pad(2 - clen, ' ');
-    os << pad << wd_ustring;
+    res << pad << wd_ustring;
   } while (++wd != first_dow);
-  os << "\n";
+  res << "\n";
+
+  if (config_["format-calendar-weekdays"].isString()) {
+    os << fmt::format(config_["format-calendar-weekdays"].asString(), res.str());
+  } else
+    os << res.str();
+}
+
+auto waybar::modules::Clock::timezones_text(std::chrono::system_clock::time_point* now)
+    -> std::string {
+  if (time_zones_.size() == 1) {
+    return "";
+  }
+  std::stringstream os;
+  waybar_time wtime;
+  for (size_t time_zone_idx = 0; time_zone_idx < time_zones_.size(); ++time_zone_idx) {
+    if (static_cast<int>(time_zone_idx) == current_time_zone_idx_) {
+      continue;
+    }
+    const date::time_zone* timezone = time_zones_[time_zone_idx];
+    if (!timezone) {
+      timezone = date::current_zone();
+    }
+    wtime = {locale_, date::make_zoned(timezone, date::floor<std::chrono::seconds>(*now))};
+    os << fmt::format(format_, wtime) << "\n";
+  }
+  return os.str();
+}
+
+auto waybar::modules::Clock::print_iso_weeknum(std::ostream& os, int weeknum) -> void {
+  std::stringstream res;
+  res << std::setfill('0') << std::setw(2) << weeknum;
+
+  if (config_["format-calendar-weeks"].isString()) {
+    os << fmt::format(config_["format-calendar-weeks"].asString(), res.str());
+  } else
+    os << res.str();
 }
 
 #ifdef HAVE_LANGINFO_1STDAY
@@ -226,9 +316,9 @@ auto waybar::modules::Clock::first_day_of_week() -> date::weekday {
       newlocale(LC_ALL, locale_.name().c_str(), nullptr)};
   if (posix_locale) {
     const int i = (std::intptr_t)nl_langinfo_l(_NL_TIME_WEEK_1STDAY, posix_locale.get());
-    auto      ymd = date::year(i / 10000) / (i / 100 % 100) / (i % 100);
-    auto      wd = date::weekday(ymd);
-    uint8_t   j = *nl_langinfo_l(_NL_TIME_FIRST_WEEKDAY, posix_locale.get());
+    auto ymd = date::year(i / 10000) / (i / 100 % 100) / (i % 100);
+    auto wd = date::weekday(ymd);
+    uint8_t j = *nl_langinfo_l(_NL_TIME_FIRST_WEEKDAY, posix_locale.get());
     return wd + date::days(j - 1);
   }
 #endif
