@@ -1,13 +1,14 @@
+#include "modules/network.hpp"
+
 #include <linux/if.h>
 #include <spdlog/spdlog.h>
 #include <sys/eventfd.h>
 
 #include <cassert>
 #include <fstream>
-#include <sstream>
 #include <optional>
+#include <sstream>
 
-#include "modules/network.hpp"
 #include "util/format.hpp"
 #ifdef WANT_RFKILL
 #include "util/rfkill.hpp"
@@ -39,9 +40,9 @@ waybar::modules::Network::readBandwidthUsage() {
     std::istringstream iss(line);
 
     std::string ifacename;
-    iss >> ifacename;  // ifacename contains "eth0:"
+    iss >> ifacename;      // ifacename contains "eth0:"
     ifacename.pop_back();  // remove trailing ':'
-    if (!checkInterface(ifacename)) {
+    if (ifacename != ifname_) {
       continue;
     }
 
@@ -58,9 +59,13 @@ waybar::modules::Network::readBandwidthUsage() {
     // Skip all the other columns in the received group
     for (int colsToSkip = 7; colsToSkip > 0; colsToSkip--) {
       // skip whitespace between columns
-      while (iss.peek() == ' ') { iss.ignore(); }
+      while (iss.peek() == ' ') {
+        iss.ignore();
+      }
       // skip the irrelevant column
-      while (iss.peek() != ' ') { iss.ignore(); }
+      while (iss.peek() != ' ') {
+        iss.ignore();
+      }
     }
     // Read transmit bytes
     iss >> t;
@@ -106,7 +111,7 @@ waybar::modules::Network::Network(const std::string &id, const Json::Value &conf
   }
 
   if (!config_["interface"].isString()) {
-    // "interface" isn't configure, then try to guess the external
+    // "interface" isn't configured, then try to guess the external
     // interface currently used for internet.
     want_route_dump_ = true;
   } else {
@@ -192,7 +197,7 @@ void waybar::modules::Network::createEventSocket() {
     }
   }
   {
-    auto               fd = nl_socket_get_fd(ev_sock_);
+    auto fd = nl_socket_get_fd(ev_sock_);
     struct epoll_event event;
     memset(&event, 0, sizeof(event));
     event.events = EPOLLIN | EPOLLET | EPOLLRDHUP;
@@ -274,8 +279,7 @@ void waybar::modules::Network::worker() {
 const std::string waybar::modules::Network::getNetworkState() const {
   if (ifid_ == -1) {
 #ifdef WANT_RFKILL
-    if (rfkill_.getState())
-      return "disabled";
+    if (rfkill_.getState()) return "disabled";
 #endif
     return "disconnected";
   }
@@ -287,7 +291,7 @@ const std::string waybar::modules::Network::getNetworkState() const {
 
 auto waybar::modules::Network::update() -> void {
   std::lock_guard<std::mutex> lock(mutex_);
-  std::string                 tooltip_format;
+  std::string tooltip_format;
 
   auto bandwidth = readBandwidthUsage();
   auto bandwidth_down = 0ull;
@@ -327,22 +331,18 @@ auto waybar::modules::Network::update() -> void {
   getState(signal_strength_);
 
   auto text = fmt::format(
-      format_,
-      fmt::arg("essid", essid_),
-      fmt::arg("signaldBm", signal_strength_dbm_),
+      format_, fmt::arg("essid", essid_), fmt::arg("signaldBm", signal_strength_dbm_),
       fmt::arg("signalStrength", signal_strength_),
-      fmt::arg("signalStrengthApp", signal_strength_app_),
-      fmt::arg("ifname", ifname_),
-      fmt::arg("netmask", netmask_),
-      fmt::arg("ipaddr", ipaddr_),
-      fmt::arg("gwaddr", gwaddr_),
-      fmt::arg("cidr", cidr_),
-      fmt::arg("frequency", fmt::format("{:.1f}", frequency_)),
+      fmt::arg("signalStrengthApp", signal_strength_app_), fmt::arg("ifname", ifname_),
+      fmt::arg("netmask", netmask_), fmt::arg("ipaddr", ipaddr_), fmt::arg("gwaddr", gwaddr_),
+      fmt::arg("cidr", cidr_), fmt::arg("frequency", fmt::format("{:.1f}", frequency_)),
       fmt::arg("icon", getIcon(signal_strength_, state_)),
       fmt::arg("bandwidthDownBits", pow_format(bandwidth_down * 8ull / interval_.count(), "b/s")),
       fmt::arg("bandwidthUpBits", pow_format(bandwidth_up * 8ull / interval_.count(), "b/s")),
       fmt::arg("bandwidthDownOctets", pow_format(bandwidth_down / interval_.count(), "o/s")),
-      fmt::arg("bandwidthUpOctets", pow_format(bandwidth_up / interval_.count(), "o/s")));
+      fmt::arg("bandwidthUpOctets", pow_format(bandwidth_up / interval_.count(), "o/s")),
+      fmt::arg("bandwidthDownBytes", pow_format(bandwidth_down / interval_.count(), "B/s")),
+      fmt::arg("bandwidthUpBytes", pow_format(bandwidth_up / interval_.count(), "B/s")));
   if (text.compare(label_.get_label()) != 0) {
     label_.set_markup(text);
     if (text.empty()) {
@@ -357,23 +357,19 @@ auto waybar::modules::Network::update() -> void {
     }
     if (!tooltip_format.empty()) {
       auto tooltip_text = fmt::format(
-          tooltip_format,
-          fmt::arg("essid", essid_),
-          fmt::arg("signaldBm", signal_strength_dbm_),
+          tooltip_format, fmt::arg("essid", essid_), fmt::arg("signaldBm", signal_strength_dbm_),
           fmt::arg("signalStrength", signal_strength_),
-          fmt::arg("signalStrengthApp", signal_strength_app_),
-          fmt::arg("ifname", ifname_),
-          fmt::arg("netmask", netmask_),
-          fmt::arg("ipaddr", ipaddr_),
-          fmt::arg("gwaddr", gwaddr_),
-          fmt::arg("cidr", cidr_),
-          fmt::arg("frequency", fmt::format("{:.1f}", frequency_)),
+          fmt::arg("signalStrengthApp", signal_strength_app_), fmt::arg("ifname", ifname_),
+          fmt::arg("netmask", netmask_), fmt::arg("ipaddr", ipaddr_), fmt::arg("gwaddr", gwaddr_),
+          fmt::arg("cidr", cidr_), fmt::arg("frequency", fmt::format("{:.1f}", frequency_)),
           fmt::arg("icon", getIcon(signal_strength_, state_)),
           fmt::arg("bandwidthDownBits",
                    pow_format(bandwidth_down * 8ull / interval_.count(), "b/s")),
           fmt::arg("bandwidthUpBits", pow_format(bandwidth_up * 8ull / interval_.count(), "b/s")),
           fmt::arg("bandwidthDownOctets", pow_format(bandwidth_down / interval_.count(), "o/s")),
-          fmt::arg("bandwidthUpOctets", pow_format(bandwidth_up / interval_.count(), "o/s")));
+          fmt::arg("bandwidthUpOctets", pow_format(bandwidth_up / interval_.count(), "o/s")),
+          fmt::arg("bandwidthDownBytes", pow_format(bandwidth_down / interval_.count(), "B/s")),
+          fmt::arg("bandwidthUpBytes", pow_format(bandwidth_up / interval_.count(), "B/s")));
       if (label_.get_tooltip_text() != tooltip_text) {
         label_.set_tooltip_text(tooltip_text);
       }
@@ -410,286 +406,279 @@ void waybar::modules::Network::clearIface() {
 }
 
 int waybar::modules::Network::handleEvents(struct nl_msg *msg, void *data) {
-  auto                        net = static_cast<waybar::modules::Network *>(data);
+  auto net = static_cast<waybar::modules::Network *>(data);
   std::lock_guard<std::mutex> lock(net->mutex_);
-  auto                        nh = nlmsg_hdr(msg);
-  bool                        is_del_event = false;
+  auto nh = nlmsg_hdr(msg);
+  bool is_del_event = false;
 
   switch (nh->nlmsg_type) {
-  case RTM_DELLINK:
-    is_del_event = true;
-  case RTM_NEWLINK: {
-    struct ifinfomsg *ifi = static_cast<struct ifinfomsg *>(NLMSG_DATA(nh));
-    ssize_t attrlen = IFLA_PAYLOAD(nh);
-    struct rtattr *ifla = IFLA_RTA(ifi);
-    const char *ifname = NULL;
-    size_t ifname_len = 0;
-    std::optional<bool> carrier;
+    case RTM_DELLINK:
+      is_del_event = true;
+    case RTM_NEWLINK: {
+      struct ifinfomsg *ifi = static_cast<struct ifinfomsg *>(NLMSG_DATA(nh));
+      ssize_t attrlen = IFLA_PAYLOAD(nh);
+      struct rtattr *ifla = IFLA_RTA(ifi);
+      const char *ifname = NULL;
+      size_t ifname_len = 0;
+      std::optional<bool> carrier;
 
-    if (net->ifid_ != -1 && ifi->ifi_index != net->ifid_) {
-      return NL_OK;
-    }
-
-    // Check if the interface goes "down" and if we want to detect the
-    // external interface.
-    if (net->ifid_ != -1 && !(ifi->ifi_flags & IFF_UP)
-        && !net->config_["interface"].isString()) {
-      // The current interface is now down, all the routes associated with
-      // it have been deleted, so start looking for a new default route.
-      spdlog::debug("network: if{} down", net->ifid_);
-      net->clearIface();
-      net->dp.emit();
-      net->want_route_dump_ = true;
-      net->askForStateDump();
-      return NL_OK;
-    }
-
-    for (; RTA_OK(ifla, attrlen); ifla = RTA_NEXT(ifla, attrlen)) {
-      switch (ifla->rta_type) {
-      case IFLA_IFNAME:
-        ifname = static_cast<const char *>(RTA_DATA(ifla));
-        ifname_len = RTA_PAYLOAD(ifla) - 1; // minus \0
-        break;
-      case IFLA_CARRIER: {
-        carrier = *(char*)RTA_DATA(ifla) == 1;
-        break;
+      if (net->ifid_ != -1 && ifi->ifi_index != net->ifid_) {
+        return NL_OK;
       }
-      }
-    }
-
-    if (!is_del_event && ifi->ifi_index == net->ifid_) {
-      // Update interface information
-      if (net->ifname_.empty() && ifname != NULL) {
-        std::string new_ifname (ifname, ifname_len);
-        net->ifname_ = new_ifname;
-      }
-      if (carrier.has_value()) {
-        if (net->carrier_ != *carrier) {
-          if (*carrier) {
-            // Ask for WiFi information
-            net->thread_timer_.wake_up();
-          } else {
-            // clear state related to WiFi connection
-            net->essid_.clear();
-            net->signal_strength_dbm_ = 0;
-            net->signal_strength_ = 0;
-            net->signal_strength_app_.clear();
-            net->frequency_ = 0.0;
-          }
-        }
-        net->carrier_ = carrier.value();
-      }
-    } else if (!is_del_event && net->ifid_ == -1) {
-      // Checking if it's an interface we care about.
-      std::string new_ifname (ifname, ifname_len);
-      if (net->checkInterface(new_ifname)) {
-        spdlog::debug("network: selecting new interface {}/{}", new_ifname, ifi->ifi_index);
-
-        net->ifname_ = new_ifname;
-        net->ifid_ = ifi->ifi_index;
-        if (carrier.has_value()) {
-          net->carrier_ = carrier.value();
-        }
-        net->thread_timer_.wake_up();
-        /* An address for this new interface should be received via an
-         * RTM_NEWADDR event either because we ask for a dump of both links
-         * and addrs, or because this interface has just been created and
-         * the addr will be sent after the RTM_NEWLINK event.
-         * So we don't need to do anything. */
-      }
-    } else if (is_del_event && net->ifid_ >= 0) {
-      // Our interface has been deleted, start looking/waiting for one we care.
-      spdlog::debug("network: interface {}/{} deleted", net->ifname_, net->ifid_);
-
-      net->clearIface();
-      net->dp.emit();
-    }
-    break;
-  }
-
-  case RTM_DELADDR:
-    is_del_event = true;
-  case RTM_NEWADDR: {
-    struct ifaddrmsg *ifa = static_cast<struct ifaddrmsg *>(NLMSG_DATA(nh));
-    ssize_t attrlen = IFA_PAYLOAD(nh);
-    struct rtattr *ifa_rta = IFA_RTA(ifa);
-
-    if ((int)ifa->ifa_index != net->ifid_) {
-      return NL_OK;
-    }
-
-    if (ifa->ifa_family != net->family_) {
-      return NL_OK;
-    }
-
-    // We ignore address mark as scope for the link or host,
-    // which should leave scope global addresses.
-    if (ifa->ifa_scope >= RT_SCOPE_LINK) {
-      return NL_OK;
-    }
-
-    for (; RTA_OK(ifa_rta, attrlen); ifa_rta = RTA_NEXT(ifa_rta, attrlen)) {
-      switch (ifa_rta->rta_type) {
-      case IFA_ADDRESS: {
-        char ipaddr[INET6_ADDRSTRLEN];
-        if (!is_del_event) {
-          net->ipaddr_ = inet_ntop(ifa->ifa_family, RTA_DATA(ifa_rta),
-                                   ipaddr, sizeof (ipaddr));
-          net->cidr_ = ifa->ifa_prefixlen;
-          switch (ifa->ifa_family) {
-          case AF_INET: {
-            struct in_addr netmask;
-            netmask.s_addr = htonl(~0 << (32 - ifa->ifa_prefixlen));
-            net->netmask_ = inet_ntop(ifa->ifa_family, &netmask,
-                                      ipaddr, sizeof (ipaddr));
-          }
-          case AF_INET6: {
-            struct in6_addr netmask;
-            for (int i = 0; i < 16; i++) {
-              int v = (i + 1) * 8 - ifa->ifa_prefixlen;
-              if (v < 0) v = 0;
-              if (v > 8) v = 8;
-              netmask.s6_addr[i] = ~0 << v;
-            }
-            net->netmask_ = inet_ntop(ifa->ifa_family, &netmask,
-                                      ipaddr, sizeof (ipaddr));
-          }
-          }
-          spdlog::debug("network: {}, new addr {}/{}", net->ifname_, net->ipaddr_, net->cidr_);
-        } else {
-          net->ipaddr_.clear();
-          net->cidr_ = 0;
-          net->netmask_.clear();
-          spdlog::debug("network: {} addr deleted {}/{}",
-                        net->ifname_,
-                        inet_ntop(ifa->ifa_family, RTA_DATA(ifa_rta),
-                                  ipaddr, sizeof (ipaddr)),
-                        ifa->ifa_prefixlen);
-        }
-        net->dp.emit();
-        break;
-      }
-      }
-    }
-    break;
-  }
-
-    char	temp_gw_addr[INET6_ADDRSTRLEN];
-  case RTM_DELROUTE:
-    is_del_event = true;
-  case RTM_NEWROUTE: {
-    // Based on https://gist.github.com/Yawning/c70d804d4b8ae78cc698
-    // to find the interface used to reach the outside world
-
-    struct rtmsg  *rtm = static_cast<struct rtmsg *>(NLMSG_DATA(nh));
-    ssize_t attrlen = RTM_PAYLOAD(nh);
-    struct rtattr *attr = RTM_RTA(rtm);
-    bool           has_gateway = false;
-    bool           has_destination = false;
-    int            temp_idx = -1;
-    uint32_t       priority = 0;
-
-
-    /* Find the message(s) concerting the main routing table, each message
-     * corresponds to a single routing table entry.
-     */
-    if (rtm->rtm_table != RT_TABLE_MAIN) {
-      return NL_OK;
-    }
-
-    /* Parse all the attributes for a single routing table entry. */
-    for (; RTA_OK(attr, attrlen); attr = RTA_NEXT(attr, attrlen)) {
-      /* Determine if this routing table entry corresponds to the default
-       * route by seeing if it has a gateway, and if a destination addr is
-       * set, that it is all 0s.
-       */
-      switch(attr->rta_type) {
-      case RTA_GATEWAY:
-        /* The gateway of the route.
-         *
-         * If someone ever needs to figure out the gateway address as well,
-         * it's here as the attribute payload.
-         */
-	inet_ntop(net->family_, RTA_DATA(attr), temp_gw_addr, sizeof(temp_gw_addr));
-        has_gateway = true;
-        break;
-      case RTA_DST: {
-        /* The destination address.
-         * Should be either missing, or maybe all 0s.  Accept both.
-         */
-        const uint32_t nr_zeroes = (net->family_ == AF_INET) ? 4 : 16;
-        unsigned char  c = 0;
-        size_t         dstlen = RTA_PAYLOAD(attr);
-        if (dstlen != nr_zeroes) {
-          break;
-        }
-        for (uint32_t i = 0; i < dstlen; i += 1) {
-          c |= *((unsigned char *)RTA_DATA(attr) + i);
-        }
-        has_destination = (c == 0);
-        break;
-      }
-      case RTA_OIF:
-        /* The output interface index. */
-        temp_idx = *static_cast<int *>(RTA_DATA(attr));
-        break;
-      case RTA_PRIORITY:
-        priority = *(uint32_t*)RTA_DATA(attr);
-        break;
-      default:
-        break;
-      }
-    }
-
-    // Check if we have a default route.
-    if (has_gateway && !has_destination && temp_idx != -1) {
-      // Check if this is the first default route we see, or if this new
-      // route have a higher priority.
-      if (!is_del_event && ((net->ifid_ == -1) || (priority < net->route_priority))) {
-        // Clear if's state for the case were there is a higher priority
-        // route on a different interface.
-        net->clearIface();
-        net->ifid_ = temp_idx;
-        net->route_priority = priority;
-        net->gwaddr_ = temp_gw_addr;
-        spdlog::debug("network: new default route via {} on if{} metric {}", temp_gw_addr, temp_idx, priority);
-
-        /* Ask ifname associated with temp_idx as well as carrier status */
-        struct ifinfomsg ifinfo_hdr = {
-          .ifi_family = AF_UNSPEC,
-          .ifi_index = temp_idx,
-        };
-        int err;
-        err = nl_send_simple(net->ev_sock_, RTM_GETLINK, NLM_F_REQUEST,
-                             &ifinfo_hdr, sizeof (ifinfo_hdr));
-        if (err < 0) {
-          spdlog::error("network: failed to ask link info: {}", err);
-          /* Ask for a dump of all links instead */
-          net->want_link_dump_ = true;
-        }
-
-        /* Also ask for the address. Asking for a addresses of a specific
-         * interface doesn't seems to work so ask for a dump of all
-         * addresses. */
-        net->want_addr_dump_ = true;
-        net->askForStateDump();
-        net->thread_timer_.wake_up();
-      } else if (is_del_event && temp_idx == net->ifid_
-                 && net->route_priority == priority) {
-        spdlog::debug("network: default route deleted {}/if{} metric {}",
-                      net->ifname_, temp_idx, priority);
 
+      // Check if the interface goes "down" and if we want to detect the
+      // external interface.
+      if (net->ifid_ != -1 && !(ifi->ifi_flags & IFF_UP) && !net->config_["interface"].isString()) {
+        // The current interface is now down, all the routes associated with
+        // it have been deleted, so start looking for a new default route.
+        spdlog::debug("network: if{} down", net->ifid_);
         net->clearIface();
         net->dp.emit();
-        /* Ask for a dump of all routes in case another one is already
-         * setup. If there's none, there'll be an event with new one
-         * later. */
         net->want_route_dump_ = true;
         net->askForStateDump();
+        return NL_OK;
       }
+
+      for (; RTA_OK(ifla, attrlen); ifla = RTA_NEXT(ifla, attrlen)) {
+        switch (ifla->rta_type) {
+          case IFLA_IFNAME:
+            ifname = static_cast<const char *>(RTA_DATA(ifla));
+            ifname_len = RTA_PAYLOAD(ifla) - 1;  // minus \0
+            break;
+          case IFLA_CARRIER: {
+            carrier = *(char *)RTA_DATA(ifla) == 1;
+            break;
+          }
+        }
+      }
+
+      if (!is_del_event && ifi->ifi_index == net->ifid_) {
+        // Update interface information
+        if (net->ifname_.empty() && ifname != NULL) {
+          std::string new_ifname(ifname, ifname_len);
+          net->ifname_ = new_ifname;
+        }
+        if (carrier.has_value()) {
+          if (net->carrier_ != *carrier) {
+            if (*carrier) {
+              // Ask for WiFi information
+              net->thread_timer_.wake_up();
+            } else {
+              // clear state related to WiFi connection
+              net->essid_.clear();
+              net->signal_strength_dbm_ = 0;
+              net->signal_strength_ = 0;
+              net->signal_strength_app_.clear();
+              net->frequency_ = 0.0;
+            }
+          }
+          net->carrier_ = carrier.value();
+        }
+      } else if (!is_del_event && net->ifid_ == -1) {
+        // Checking if it's an interface we care about.
+        std::string new_ifname(ifname, ifname_len);
+        if (net->checkInterface(new_ifname)) {
+          spdlog::debug("network: selecting new interface {}/{}", new_ifname, ifi->ifi_index);
+
+          net->ifname_ = new_ifname;
+          net->ifid_ = ifi->ifi_index;
+          if (carrier.has_value()) {
+            net->carrier_ = carrier.value();
+          }
+          net->thread_timer_.wake_up();
+          /* An address for this new interface should be received via an
+           * RTM_NEWADDR event either because we ask for a dump of both links
+           * and addrs, or because this interface has just been created and
+           * the addr will be sent after the RTM_NEWLINK event.
+           * So we don't need to do anything. */
+        }
+      } else if (is_del_event && net->ifid_ >= 0) {
+        // Our interface has been deleted, start looking/waiting for one we care.
+        spdlog::debug("network: interface {}/{} deleted", net->ifname_, net->ifid_);
+
+        net->clearIface();
+        net->dp.emit();
+      }
+      break;
+    }
+
+    case RTM_DELADDR:
+      is_del_event = true;
+    case RTM_NEWADDR: {
+      struct ifaddrmsg *ifa = static_cast<struct ifaddrmsg *>(NLMSG_DATA(nh));
+      ssize_t attrlen = IFA_PAYLOAD(nh);
+      struct rtattr *ifa_rta = IFA_RTA(ifa);
+
+      if ((int)ifa->ifa_index != net->ifid_) {
+        return NL_OK;
+      }
+
+      if (ifa->ifa_family != net->family_) {
+        return NL_OK;
+      }
+
+      // We ignore address mark as scope for the link or host,
+      // which should leave scope global addresses.
+      if (ifa->ifa_scope >= RT_SCOPE_LINK) {
+        return NL_OK;
+      }
+
+      for (; RTA_OK(ifa_rta, attrlen); ifa_rta = RTA_NEXT(ifa_rta, attrlen)) {
+        switch (ifa_rta->rta_type) {
+          case IFA_ADDRESS: {
+            char ipaddr[INET6_ADDRSTRLEN];
+            if (!is_del_event) {
+              net->ipaddr_ = inet_ntop(ifa->ifa_family, RTA_DATA(ifa_rta), ipaddr, sizeof(ipaddr));
+              net->cidr_ = ifa->ifa_prefixlen;
+              switch (ifa->ifa_family) {
+                case AF_INET: {
+                  struct in_addr netmask;
+                  netmask.s_addr = htonl(~0 << (32 - ifa->ifa_prefixlen));
+                  net->netmask_ = inet_ntop(ifa->ifa_family, &netmask, ipaddr, sizeof(ipaddr));
+                }
+                case AF_INET6: {
+                  struct in6_addr netmask;
+                  for (int i = 0; i < 16; i++) {
+                    int v = (i + 1) * 8 - ifa->ifa_prefixlen;
+                    if (v < 0) v = 0;
+                    if (v > 8) v = 8;
+                    netmask.s6_addr[i] = ~0 << v;
+                  }
+                  net->netmask_ = inet_ntop(ifa->ifa_family, &netmask, ipaddr, sizeof(ipaddr));
+                }
+              }
+              spdlog::debug("network: {}, new addr {}/{}", net->ifname_, net->ipaddr_, net->cidr_);
+            } else {
+              net->ipaddr_.clear();
+              net->cidr_ = 0;
+              net->netmask_.clear();
+              spdlog::debug("network: {} addr deleted {}/{}", net->ifname_,
+                            inet_ntop(ifa->ifa_family, RTA_DATA(ifa_rta), ipaddr, sizeof(ipaddr)),
+                            ifa->ifa_prefixlen);
+            }
+            net->dp.emit();
+            break;
+          }
+        }
+      }
+      break;
+    }
+
+      char temp_gw_addr[INET6_ADDRSTRLEN];
+    case RTM_DELROUTE:
+      is_del_event = true;
+    case RTM_NEWROUTE: {
+      // Based on https://gist.github.com/Yawning/c70d804d4b8ae78cc698
+      // to find the interface used to reach the outside world
+
+      struct rtmsg *rtm = static_cast<struct rtmsg *>(NLMSG_DATA(nh));
+      ssize_t attrlen = RTM_PAYLOAD(nh);
+      struct rtattr *attr = RTM_RTA(rtm);
+      bool has_gateway = false;
+      bool has_destination = false;
+      int temp_idx = -1;
+      uint32_t priority = 0;
+
+      /* Find the message(s) concerting the main routing table, each message
+       * corresponds to a single routing table entry.
+       */
+      if (rtm->rtm_table != RT_TABLE_MAIN) {
+        return NL_OK;
+      }
+
+      /* Parse all the attributes for a single routing table entry. */
+      for (; RTA_OK(attr, attrlen); attr = RTA_NEXT(attr, attrlen)) {
+        /* Determine if this routing table entry corresponds to the default
+         * route by seeing if it has a gateway, and if a destination addr is
+         * set, that it is all 0s.
+         */
+        switch (attr->rta_type) {
+          case RTA_GATEWAY:
+            /* The gateway of the route.
+             *
+             * If someone ever needs to figure out the gateway address as well,
+             * it's here as the attribute payload.
+             */
+            inet_ntop(net->family_, RTA_DATA(attr), temp_gw_addr, sizeof(temp_gw_addr));
+            has_gateway = true;
+            break;
+          case RTA_DST: {
+            /* The destination address.
+             * Should be either missing, or maybe all 0s.  Accept both.
+             */
+            const uint32_t nr_zeroes = (net->family_ == AF_INET) ? 4 : 16;
+            unsigned char c = 0;
+            size_t dstlen = RTA_PAYLOAD(attr);
+            if (dstlen != nr_zeroes) {
+              break;
+            }
+            for (uint32_t i = 0; i < dstlen; i += 1) {
+              c |= *((unsigned char *)RTA_DATA(attr) + i);
+            }
+            has_destination = (c == 0);
+            break;
+          }
+          case RTA_OIF:
+            /* The output interface index. */
+            temp_idx = *static_cast<int *>(RTA_DATA(attr));
+            break;
+          case RTA_PRIORITY:
+            priority = *(uint32_t *)RTA_DATA(attr);
+            break;
+          default:
+            break;
+        }
+      }
+
+      // Check if we have a default route.
+      if (has_gateway && !has_destination && temp_idx != -1) {
+        // Check if this is the first default route we see, or if this new
+        // route have a higher priority.
+        if (!is_del_event && ((net->ifid_ == -1) || (priority < net->route_priority))) {
+          // Clear if's state for the case were there is a higher priority
+          // route on a different interface.
+          net->clearIface();
+          net->ifid_ = temp_idx;
+          net->route_priority = priority;
+          net->gwaddr_ = temp_gw_addr;
+          spdlog::debug("network: new default route via {} on if{} metric {}", temp_gw_addr,
+                        temp_idx, priority);
+
+          /* Ask ifname associated with temp_idx as well as carrier status */
+          struct ifinfomsg ifinfo_hdr = {
+              .ifi_family = AF_UNSPEC,
+              .ifi_index = temp_idx,
+          };
+          int err;
+          err = nl_send_simple(net->ev_sock_, RTM_GETLINK, NLM_F_REQUEST, &ifinfo_hdr,
+                               sizeof(ifinfo_hdr));
+          if (err < 0) {
+            spdlog::error("network: failed to ask link info: {}", err);
+            /* Ask for a dump of all links instead */
+            net->want_link_dump_ = true;
+          }
+
+          /* Also ask for the address. Asking for a addresses of a specific
+           * interface doesn't seems to work so ask for a dump of all
+           * addresses. */
+          net->want_addr_dump_ = true;
+          net->askForStateDump();
+          net->thread_timer_.wake_up();
+        } else if (is_del_event && temp_idx == net->ifid_ && net->route_priority == priority) {
+          spdlog::debug("network: default route deleted {}/if{} metric {}", net->ifname_, temp_idx,
+                        priority);
+
+          net->clearIface();
+          net->dp.emit();
+          /* Ask for a dump of all routes in case another one is already
+           * setup. If there's none, there'll be an event with new one
+           * later. */
+          net->want_route_dump_ = true;
+          net->askForStateDump();
+        }
+      }
+      break;
     }
-    break;
-  }
   }
 
   return NL_OK;
@@ -698,30 +687,26 @@ int waybar::modules::Network::handleEvents(struct nl_msg *msg, void *data) {
 void waybar::modules::Network::askForStateDump(void) {
   /* We need to wait until the current dump is done before sending new
    * messages. handleEventsDone() is called when a dump is done. */
-  if (dump_in_progress_)
-    return;
+  if (dump_in_progress_) return;
 
   struct rtgenmsg rt_hdr = {
-    .rtgen_family = AF_UNSPEC,
+      .rtgen_family = AF_UNSPEC,
   };
 
   if (want_route_dump_) {
     rt_hdr.rtgen_family = family_;
-    nl_send_simple(ev_sock_, RTM_GETROUTE, NLM_F_DUMP,
-                   &rt_hdr, sizeof (rt_hdr));
+    nl_send_simple(ev_sock_, RTM_GETROUTE, NLM_F_DUMP, &rt_hdr, sizeof(rt_hdr));
     want_route_dump_ = false;
     dump_in_progress_ = true;
 
   } else if (want_link_dump_) {
-    nl_send_simple(ev_sock_, RTM_GETLINK, NLM_F_DUMP,
-                   &rt_hdr, sizeof (rt_hdr));
+    nl_send_simple(ev_sock_, RTM_GETLINK, NLM_F_DUMP, &rt_hdr, sizeof(rt_hdr));
     want_link_dump_ = false;
     dump_in_progress_ = true;
 
   } else if (want_addr_dump_) {
     rt_hdr.rtgen_family = family_;
-    nl_send_simple(ev_sock_, RTM_GETADDR, NLM_F_DUMP,
-                   &rt_hdr, sizeof (rt_hdr));
+    nl_send_simple(ev_sock_, RTM_GETADDR, NLM_F_DUMP, &rt_hdr, sizeof(rt_hdr));
     want_addr_dump_ = false;
     dump_in_progress_ = true;
   }
@@ -735,10 +720,10 @@ int waybar::modules::Network::handleEventsDone(struct nl_msg *msg, void *data) {
 }
 
 int waybar::modules::Network::handleScan(struct nl_msg *msg, void *data) {
-  auto              net = static_cast<waybar::modules::Network *>(data);
-  auto              gnlh = static_cast<genlmsghdr *>(nlmsg_data(nlmsg_hdr(msg)));
-  struct nlattr *   tb[NL80211_ATTR_MAX + 1];
-  struct nlattr *   bss[NL80211_BSS_MAX + 1];
+  auto net = static_cast<waybar::modules::Network *>(data);
+  auto gnlh = static_cast<genlmsghdr *>(nlmsg_data(nlmsg_hdr(msg)));
+  struct nlattr *tb[NL80211_ATTR_MAX + 1];
+  struct nlattr *bss[NL80211_BSS_MAX + 1];
   struct nla_policy bss_policy[NL80211_BSS_MAX + 1]{};
   bss_policy[NL80211_BSS_TSF].type = NLA_U64;
   bss_policy[NL80211_BSS_FREQUENCY].type = NLA_U32;
@@ -750,8 +735,8 @@ int waybar::modules::Network::handleScan(struct nl_msg *msg, void *data) {
   bss_policy[NL80211_BSS_SIGNAL_UNSPEC].type = NLA_U8;
   bss_policy[NL80211_BSS_STATUS].type = NLA_U32;
 
-  if (nla_parse(
-          tb, NL80211_ATTR_MAX, genlmsg_attrdata(gnlh, 0), genlmsg_attrlen(gnlh, 0), nullptr) < 0) {
+  if (nla_parse(tb, NL80211_ATTR_MAX, genlmsg_attrdata(gnlh, 0), genlmsg_attrlen(gnlh, 0),
+                nullptr) < 0) {
     return NL_SKIP;
   }
   if (tb[NL80211_ATTR_BSS] == nullptr) {
@@ -771,16 +756,16 @@ int waybar::modules::Network::handleScan(struct nl_msg *msg, void *data) {
 
 void waybar::modules::Network::parseEssid(struct nlattr **bss) {
   if (bss[NL80211_BSS_INFORMATION_ELEMENTS] != nullptr) {
-    auto       ies = static_cast<char *>(nla_data(bss[NL80211_BSS_INFORMATION_ELEMENTS]));
-    auto       ies_len = nla_len(bss[NL80211_BSS_INFORMATION_ELEMENTS]);
+    auto ies = static_cast<char *>(nla_data(bss[NL80211_BSS_INFORMATION_ELEMENTS]));
+    auto ies_len = nla_len(bss[NL80211_BSS_INFORMATION_ELEMENTS]);
     const auto hdr_len = 2;
     while (ies_len > hdr_len && ies[0] != 0) {
       ies_len -= ies[1] + hdr_len;
       ies += ies[1] + hdr_len;
     }
     if (ies_len > hdr_len && ies_len > ies[1] + hdr_len) {
-      auto        essid_begin = ies + hdr_len;
-      auto        essid_end = essid_begin + ies[1];
+      auto essid_begin = ies + hdr_len;
+      auto essid_end = essid_begin + ies[1];
       std::string essid_raw;
       std::copy(essid_begin, essid_end, std::back_inserter(essid_raw));
       essid_ = Glib::Markup::escape_text(essid_raw);
@@ -800,8 +785,10 @@ void waybar::modules::Network::parseSignal(struct nlattr **bss) {
     const int hardwareOptimum = -45;
     const int hardwareMin = -90;
     const int strength =
-        100 - ((abs(signal_strength_dbm_ - hardwareOptimum) / double{hardwareOptimum - hardwareMin}) * 100);
-    signal_strength_ = std::clamp(strength, 0, 100);  
+        100 -
+        ((abs(signal_strength_dbm_ - hardwareOptimum) / double{hardwareOptimum - hardwareMin}) *
+         100);
+    signal_strength_ = std::clamp(strength, 0, 100);
 
     if (signal_strength_dbm_ >= -50) {
       signal_strength_app_ = "Great Connectivity";
@@ -825,7 +812,7 @@ void waybar::modules::Network::parseSignal(struct nlattr **bss) {
 void waybar::modules::Network::parseFreq(struct nlattr **bss) {
   if (bss[NL80211_BSS_FREQUENCY] != nullptr) {
     // in GHz
-    frequency_ = (double) nla_get_u32(bss[NL80211_BSS_FREQUENCY]) / 1000;
+    frequency_ = (double)nla_get_u32(bss[NL80211_BSS_FREQUENCY]) / 1000;
   }
 }
 
@@ -849,9 +836,8 @@ auto waybar::modules::Network::getInfo() -> void {
   if (nl_msg == nullptr) {
     return;
   }
-  if (genlmsg_put(
-          nl_msg, NL_AUTO_PORT, NL_AUTO_SEQ, nl80211_id_, 0, NLM_F_DUMP, NL80211_CMD_GET_SCAN, 0) ==
-          nullptr ||
+  if (genlmsg_put(nl_msg, NL_AUTO_PORT, NL_AUTO_SEQ, nl80211_id_, 0, NLM_F_DUMP,
+                  NL80211_CMD_GET_SCAN, 0) == nullptr ||
       nla_put_u32(nl_msg, NL80211_ATTR_IFINDEX, ifid_) < 0) {
     nlmsg_free(nl_msg);
     return;
